@@ -542,8 +542,6 @@ class Nag_Task
      */
     public function toggleComplete()
     {
-        $horde_alarm = $GLOBALS['injector']->getInstance('Horde_Alarm');
-
         if ($this->completed) {
             $this->completed_date = null;
             $this->completed = false;
@@ -558,15 +556,9 @@ class Nag_Task
                         substr($completion, 6, 2));
                 }
             }
-            $alarm = $this->toAlarm();
-            if ($alarm) {
-                $horde_alarm->set($alarm);
-            }
             return;
         }
 
-        $horde_alarm->delete($this->uid);
-
         if ($this->recurs()) {
             /* Get current occurrence (task due date) */
             $current = $this->recurrence->nextActiveRecurrence(new Horde_Date($this->due));
@@ -582,11 +574,6 @@ class Nag_Task
                  * occurence. */
                 if ($next = $this->recurrence->nextActiveRecurrence($current)) {
                     $this->completed = false;
-                    $alarm = $this->toAlarm();
-                    if ($alarm) {
-                        $alarm['start'] = new Horde_Date($next);
-                        $horde_alarm->set($alarm);
-                    }
                     return;
                 }
             }
